Documentation
¶
Overview ¶
Package _go is a reverse proxy.
It translates gRPC into RESTful JSON APIs.
Index ¶
- Constants
- Variables
- func RegisterBroadageServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
- func RegisterBroadageServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client BroadageServiceClient) error
- func RegisterBroadageServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, ...) (err error)
- func RegisterBroadageServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, server BroadageServiceServer) error
- func RegisterBroadageServiceServer(s grpc.ServiceRegistrar, srv BroadageServiceServer)
- type ActionCode
- type ActionSubcode
- func (ActionSubcode) Descriptor() protoreflect.EnumDescriptor
- func (x ActionSubcode) Enum() *ActionSubcode
- func (ActionSubcode) EnumDescriptor() ([]byte, []int)deprecated
- func (x ActionSubcode) Number() protoreflect.EnumNumber
- func (x ActionSubcode) String() string
- func (ActionSubcode) Type() protoreflect.EnumType
- type Actor
- type ActorType
- type BroadageServiceClient
- type BroadageServiceServer
- type EventCode
- type GetLiveMatchesRequest
- type GetLiveMatchesResponse
- func (*GetLiveMatchesResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetLiveMatchesResponse) GetMatches() []*MatchKey
- func (*GetLiveMatchesResponse) ProtoMessage()
- func (x *GetLiveMatchesResponse) ProtoReflect() protoreflect.Message
- func (x *GetLiveMatchesResponse) Reset()
- func (x *GetLiveMatchesResponse) String() string
- type GetMatchPlayersRequest
- func (*GetMatchPlayersRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetMatchPlayersRequest) GetMatchFid() string
- func (*GetMatchPlayersRequest) ProtoMessage()
- func (x *GetMatchPlayersRequest) ProtoReflect() protoreflect.Message
- func (x *GetMatchPlayersRequest) Reset()
- func (x *GetMatchPlayersRequest) String() string
- type GetMatchPlayersResponse
- func (*GetMatchPlayersResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetMatchPlayersResponse) GetAwayTeam() *MatchTeam
- func (x *GetMatchPlayersResponse) GetHomeTeam() *MatchTeam
- func (*GetMatchPlayersResponse) ProtoMessage()
- func (x *GetMatchPlayersResponse) ProtoReflect() protoreflect.Message
- func (x *GetMatchPlayersResponse) Reset()
- func (x *GetMatchPlayersResponse) String() string
- type GetPlayByPlayRequest
- func (*GetPlayByPlayRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetPlayByPlayRequest) GetFromSequenceNo() int32
- func (x *GetPlayByPlayRequest) GetMatchFid() string
- func (*GetPlayByPlayRequest) ProtoMessage()
- func (x *GetPlayByPlayRequest) ProtoReflect() protoreflect.Message
- func (x *GetPlayByPlayRequest) Reset()
- func (x *GetPlayByPlayRequest) String() string
- type GetPlayByPlayResponse
- func (*GetPlayByPlayResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetPlayByPlayResponse) GetActions() []*MatchAction
- func (x *GetPlayByPlayResponse) GetEvents() []*MatchEvent
- func (*GetPlayByPlayResponse) ProtoMessage()
- func (x *GetPlayByPlayResponse) ProtoReflect() protoreflect.Message
- func (x *GetPlayByPlayResponse) Reset()
- func (x *GetPlayByPlayResponse) String() string
- type GetTeamPlayersRequest
- func (*GetTeamPlayersRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetTeamPlayersRequest) GetTeamFid() string
- func (*GetTeamPlayersRequest) ProtoMessage()
- func (x *GetTeamPlayersRequest) ProtoReflect() protoreflect.Message
- func (x *GetTeamPlayersRequest) Reset()
- func (x *GetTeamPlayersRequest) String() string
- type GetTeamPlayersResponse
- func (*GetTeamPlayersResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetTeamPlayersResponse) GetPlayers() []*TeamPlayer
- func (*GetTeamPlayersResponse) ProtoMessage()
- func (x *GetTeamPlayersResponse) ProtoReflect() protoreflect.Message
- func (x *GetTeamPlayersResponse) Reset()
- func (x *GetTeamPlayersResponse) String() string
- type MatchAction
- func (*MatchAction) Descriptor() ([]byte, []int)deprecated
- func (x *MatchAction) GetActor() *Actor
- func (x *MatchAction) GetCode() ActionCode
- func (x *MatchAction) GetFid() string
- func (x *MatchAction) GetPeriod() int32
- func (x *MatchAction) GetResult() bool
- func (x *MatchAction) GetSequence() int32
- func (x *MatchAction) GetSubCode() ActionSubcode
- func (x *MatchAction) GetTeamFid() string
- func (x *MatchAction) GetTime() int32
- func (x *MatchAction) GetValue() int32
- func (*MatchAction) ProtoMessage()
- func (x *MatchAction) ProtoReflect() protoreflect.Message
- func (x *MatchAction) Reset()
- func (x *MatchAction) String() string
- type MatchEvent
- func (*MatchEvent) Descriptor() ([]byte, []int)deprecated
- func (x *MatchEvent) GetCode() EventCode
- func (x *MatchEvent) GetFid() string
- func (x *MatchEvent) GetPeriod() int32
- func (x *MatchEvent) GetSequence() int32
- func (x *MatchEvent) GetTime() int32
- func (*MatchEvent) ProtoMessage()
- func (x *MatchEvent) ProtoReflect() protoreflect.Message
- func (x *MatchEvent) Reset()
- func (x *MatchEvent) String() string
- type MatchKey
- type MatchPlayer
- func (*MatchPlayer) Descriptor() ([]byte, []int)deprecated
- func (x *MatchPlayer) GetCaptain() bool
- func (x *MatchPlayer) GetFid() string
- func (x *MatchPlayer) GetNumber() string
- func (x *MatchPlayer) GetStart() bool
- func (*MatchPlayer) ProtoMessage()
- func (x *MatchPlayer) ProtoReflect() protoreflect.Message
- func (x *MatchPlayer) Reset()
- func (x *MatchPlayer) String() string
- type MatchTeam
- type TeamPlayer
- func (*TeamPlayer) Descriptor() ([]byte, []int)deprecated
- func (x *TeamPlayer) GetFid() string
- func (x *TeamPlayer) GetLicense() string
- func (x *TeamPlayer) GetName() string
- func (x *TeamPlayer) GetNumber() string
- func (x *TeamPlayer) GetSurname() string
- func (*TeamPlayer) ProtoMessage()
- func (x *TeamPlayer) ProtoReflect() protoreflect.Message
- func (x *TeamPlayer) Reset()
- func (x *TeamPlayer) String() string
- type UnimplementedBroadageServiceServer
- func (UnimplementedBroadageServiceServer) GetLiveMatches(context.Context, *GetLiveMatchesRequest) (*GetLiveMatchesResponse, error)
- func (UnimplementedBroadageServiceServer) GetMatchPlayers(context.Context, *GetMatchPlayersRequest) (*GetMatchPlayersResponse, error)
- func (UnimplementedBroadageServiceServer) GetPlayByPlay(context.Context, *GetPlayByPlayRequest) (*GetPlayByPlayResponse, error)
- func (UnimplementedBroadageServiceServer) GetTeamPlayers(context.Context, *GetTeamPlayersRequest) (*GetTeamPlayersResponse, error)
- type UnsafeBroadageServiceServer
Constants ¶
const ( BroadageService_GetLiveMatches_FullMethodName = "/core.broadage.v1.BroadageService/GetLiveMatches" BroadageService_GetTeamPlayers_FullMethodName = "/core.broadage.v1.BroadageService/GetTeamPlayers" BroadageService_GetMatchPlayers_FullMethodName = "/core.broadage.v1.BroadageService/GetMatchPlayers" BroadageService_GetPlayByPlay_FullMethodName = "/core.broadage.v1.BroadageService/GetPlayByPlay" )
Variables ¶
var ( EventCode_name = map[int32]string{ 0: "EVENT_CODE_UNSPECIFIED", 1: "EVENT_CODE_SOM", 2: "EVENT_CODE_EOM", 3: "EVENT_CODE_SOQ", 4: "EVENT_CODE_EOQ", } EventCode_value = map[string]int32{ "EVENT_CODE_UNSPECIFIED": 0, "EVENT_CODE_SOM": 1, "EVENT_CODE_EOM": 2, "EVENT_CODE_SOQ": 3, "EVENT_CODE_EOQ": 4, } )
Enum value maps for EventCode.
var ( ActionSubcode_name = map[int32]string{ 0: "ACTION_SUBCODE_UNSPECIFIED", 1: "ACTION_SUBCODE_IN_ARC", 2: "ACTION_SUBCODE_OUT_ARC", 3: "ACTION_SUBCODE_FREE_THROW", 4: "ACTION_SUBCODE_DUNK", 5: "ACTION_SUBCODE_OFFENSIVE_REBOUND", 6: "ACTION_SUBCODE_DEFENSIVE_REBOUND", 7: "ACTION_SUBCODE_RECEIVE_BLOCK", 8: "ACTION_SUBCODE_RECEIVE_FOUL", 9: "ACTION_SUBCODE_TECHNICAL", 10: "ACTION_SUBCODE_UNSPORTSMANLIKE", 11: "ACTION_SUBCODE_DISQUALIFYING", 12: "ACTION_SUBCODE_BRAWL", 13: "ACTION_SUBCODE_SWAP_IN", 14: "ACTION_SUBCODE_SWAP_OUT", } ActionSubcode_value = map[string]int32{ "ACTION_SUBCODE_UNSPECIFIED": 0, "ACTION_SUBCODE_IN_ARC": 1, "ACTION_SUBCODE_OUT_ARC": 2, "ACTION_SUBCODE_FREE_THROW": 3, "ACTION_SUBCODE_DUNK": 4, "ACTION_SUBCODE_OFFENSIVE_REBOUND": 5, "ACTION_SUBCODE_DEFENSIVE_REBOUND": 6, "ACTION_SUBCODE_RECEIVE_BLOCK": 7, "ACTION_SUBCODE_RECEIVE_FOUL": 8, "ACTION_SUBCODE_TECHNICAL": 9, "ACTION_SUBCODE_UNSPORTSMANLIKE": 10, "ACTION_SUBCODE_DISQUALIFYING": 11, "ACTION_SUBCODE_BRAWL": 12, "ACTION_SUBCODE_SWAP_IN": 13, "ACTION_SUBCODE_SWAP_OUT": 14, } )
Enum value maps for ActionSubcode.
var ( ActionCode_name = map[int32]string{ 0: "ACTION_CODE_UNSPECIFIED", 1: "ACTION_CODE_POINTS", 2: "ACTION_CODE_FOUL", 3: "ACTION_CODE_RECEIVE", 4: "ACTION_CODE_REBOUND", 5: "ACTION_CODE_ASSIST", 6: "ACTION_CODE_TURNOVER", 7: "ACTION_CODE_STEAL", 8: "ACTION_CODE_BLOCK", 9: "ACTION_CODE_SWAP", 10: "ACTION_CODE_TIMEOUT", } ActionCode_value = map[string]int32{ "ACTION_CODE_UNSPECIFIED": 0, "ACTION_CODE_POINTS": 1, "ACTION_CODE_FOUL": 2, "ACTION_CODE_RECEIVE": 3, "ACTION_CODE_REBOUND": 4, "ACTION_CODE_ASSIST": 5, "ACTION_CODE_TURNOVER": 6, "ACTION_CODE_STEAL": 7, "ACTION_CODE_BLOCK": 8, "ACTION_CODE_SWAP": 9, "ACTION_CODE_TIMEOUT": 10, } )
Enum value maps for ActionCode.
var ( ActorType_name = map[int32]string{ 0: "ACTOR_TYPE_UNSPECIFIED", 1: "ACTOR_TYPE_PLAYER", 2: "ACTOR_TYPE_TEAM", 3: "ACTOR_TYPE_COACH", } ActorType_value = map[string]int32{ "ACTOR_TYPE_UNSPECIFIED": 0, "ACTOR_TYPE_PLAYER": 1, "ACTOR_TYPE_TEAM": 2, "ACTOR_TYPE_COACH": 3, } )
Enum value maps for ActorType.
var BroadageService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "core.broadage.v1.BroadageService", HandlerType: (*BroadageServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetLiveMatches", Handler: _BroadageService_GetLiveMatches_Handler, }, { MethodName: "GetTeamPlayers", Handler: _BroadageService_GetTeamPlayers_Handler, }, { MethodName: "GetMatchPlayers", Handler: _BroadageService_GetMatchPlayers_Handler, }, { MethodName: "GetPlayByPlay", Handler: _BroadageService_GetPlayByPlay_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "api/proto/v1/proto_broadage.proto", }
BroadageService_ServiceDesc is the grpc.ServiceDesc for BroadageService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_api_proto_v1_proto_broadage_proto protoreflect.FileDescriptor
Functions ¶
func RegisterBroadageServiceHandler ¶
func RegisterBroadageServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
RegisterBroadageServiceHandler registers the http handlers for service BroadageService to "mux". The handlers forward requests to the grpc endpoint over "conn".
func RegisterBroadageServiceHandlerClient ¶
func RegisterBroadageServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client BroadageServiceClient) error
RegisterBroadageServiceHandlerClient registers the http handlers for service BroadageService to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "BroadageServiceClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "BroadageServiceClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "BroadageServiceClient" to call the correct interceptors.
func RegisterBroadageServiceHandlerFromEndpoint ¶
func RegisterBroadageServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)
RegisterBroadageServiceHandlerFromEndpoint is same as RegisterBroadageServiceHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.
func RegisterBroadageServiceHandlerServer ¶
func RegisterBroadageServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, server BroadageServiceServer) error
RegisterBroadageServiceHandlerServer registers the http handlers for service BroadageService to "mux". UnaryRPC :call BroadageServiceServer directly. StreamingRPC :currently unsupported pending https://github.com/grpc/grpc-go/issues/906. Note that using this registration option will cause many gRPC library features to stop working. Consider using RegisterBroadageServiceHandlerFromEndpoint instead.
func RegisterBroadageServiceServer ¶
func RegisterBroadageServiceServer(s grpc.ServiceRegistrar, srv BroadageServiceServer)
Types ¶
type ActionCode ¶ added in v1.0.1
type ActionCode int32
CODE represents the code of an action in a match.
const ( // ACTION_CODE_UNSPECIFIED represents an unspecified action. ActionCode_ACTION_CODE_UNSPECIFIED ActionCode = 0 // ACTION_CODE_POINTS represents a points action. ActionCode_ACTION_CODE_POINTS ActionCode = 1 // ACTION_CODE_FOUL represents a foul action. ActionCode_ACTION_CODE_FOUL ActionCode = 2 // ACTION_CODE_RECEIVE represents a receive action. ActionCode_ACTION_CODE_RECEIVE ActionCode = 3 // ACTION_CODE_REBOUND represents a rebound action. ActionCode_ACTION_CODE_REBOUND ActionCode = 4 // ACTION_CODE_ASSIST represents an assist action. ActionCode_ACTION_CODE_ASSIST ActionCode = 5 // ACTION_CODE_TURNOVER represents a turnover action. ActionCode_ACTION_CODE_TURNOVER ActionCode = 6 // ACTION_CODE_STEAL represents a steal action. ActionCode_ACTION_CODE_STEAL ActionCode = 7 // ACTION_CODE_BLOCK represents a block action. ActionCode_ACTION_CODE_BLOCK ActionCode = 8 // ACTION_CODE_SWAP represents a swap action. ActionCode_ACTION_CODE_SWAP ActionCode = 9 // ACTION_CODE_TIMEOUT represents a timeout action. ActionCode_ACTION_CODE_TIMEOUT ActionCode = 10 )
func (ActionCode) Descriptor ¶ added in v1.0.1
func (ActionCode) Descriptor() protoreflect.EnumDescriptor
func (ActionCode) Enum ¶ added in v1.0.1
func (x ActionCode) Enum() *ActionCode
func (ActionCode) EnumDescriptor
deprecated
added in
v1.0.1
func (ActionCode) EnumDescriptor() ([]byte, []int)
Deprecated: Use ActionCode.Descriptor instead.
func (ActionCode) Number ¶ added in v1.0.1
func (x ActionCode) Number() protoreflect.EnumNumber
func (ActionCode) String ¶ added in v1.0.1
func (x ActionCode) String() string
func (ActionCode) Type ¶ added in v1.0.1
func (ActionCode) Type() protoreflect.EnumType
type ActionSubcode ¶ added in v1.0.1
type ActionSubcode int32
SUB_CODE represents the sub-code of an action in a match.
const ( // UNSPECIFIED represents an unspecified sub-code. ActionSubcode_ACTION_SUBCODE_UNSPECIFIED ActionSubcode = 0 // IN_ARC represents an action inside the arc. ActionSubcode_ACTION_SUBCODE_IN_ARC ActionSubcode = 1 // OUT_ARC represents an action outside the arc. ActionSubcode_ACTION_SUBCODE_OUT_ARC ActionSubcode = 2 // FREE_THROW represents a free throw action. ActionSubcode_ACTION_SUBCODE_FREE_THROW ActionSubcode = 3 // DUNK represents a dunk action. ActionSubcode_ACTION_SUBCODE_DUNK ActionSubcode = 4 // OFFENSIVE_REBOUND represents an offensive rebound action. ActionSubcode_ACTION_SUBCODE_OFFENSIVE_REBOUND ActionSubcode = 5 // DEFENSIVE_REBOUND represents a defensive rebound action. ActionSubcode_ACTION_SUBCODE_DEFENSIVE_REBOUND ActionSubcode = 6 // RECEIVE_BLOCK represents a block received action. ActionSubcode_ACTION_SUBCODE_RECEIVE_BLOCK ActionSubcode = 7 // RECEIVE_FOUL represents a foul received action. ActionSubcode_ACTION_SUBCODE_RECEIVE_FOUL ActionSubcode = 8 // TECHNICAL represents a technical foul action. ActionSubcode_ACTION_SUBCODE_TECHNICAL ActionSubcode = 9 // UNSPORTSMANLIKE represents an unsportsmanlike foul action. ActionSubcode_ACTION_SUBCODE_UNSPORTSMANLIKE ActionSubcode = 10 // DISQUALIFYING represents a disqualifying foul action. ActionSubcode_ACTION_SUBCODE_DISQUALIFYING ActionSubcode = 11 // BRAWL represents a brawl action. ActionSubcode_ACTION_SUBCODE_BRAWL ActionSubcode = 12 // SWAP_IN represents a swap in action. ActionSubcode_ACTION_SUBCODE_SWAP_IN ActionSubcode = 13 // SWAP_OUT represents a swap out action. ActionSubcode_ACTION_SUBCODE_SWAP_OUT ActionSubcode = 14 )
func (ActionSubcode) Descriptor ¶ added in v1.0.1
func (ActionSubcode) Descriptor() protoreflect.EnumDescriptor
func (ActionSubcode) Enum ¶ added in v1.0.1
func (x ActionSubcode) Enum() *ActionSubcode
func (ActionSubcode) EnumDescriptor
deprecated
added in
v1.0.1
func (ActionSubcode) EnumDescriptor() ([]byte, []int)
Deprecated: Use ActionSubcode.Descriptor instead.
func (ActionSubcode) Number ¶ added in v1.0.1
func (x ActionSubcode) Number() protoreflect.EnumNumber
func (ActionSubcode) String ¶ added in v1.0.1
func (x ActionSubcode) String() string
func (ActionSubcode) Type ¶ added in v1.0.1
func (ActionSubcode) Type() protoreflect.EnumType
type Actor ¶
type Actor struct {
// type is the type of the Actor.
Type ActorType `protobuf:"varint,1,opt,name=type,proto3,enum=core.broadage.v1.ActorType" json:"type,omitempty"`
// fid is the unique identifier of the Actor when the actor type is player or team.
Fid *string `protobuf:"bytes,2,opt,name=fid,proto3,oneof" json:"fid,omitempty"`
// contains filtered or unexported fields
}
ActorType represents the type of Actor.
func (*Actor) Descriptor
deprecated
func (*Actor) ProtoMessage ¶
func (*Actor) ProtoMessage()
func (*Actor) ProtoReflect ¶
func (x *Actor) ProtoReflect() protoreflect.Message
type ActorType ¶
type ActorType int32
Actor represents the type of Actor in a match.
const ( // UNSPECIFIED represents an unspecified actor type. ActorType_ACTOR_TYPE_UNSPECIFIED ActorType = 0 // PLAYER represents a player in the match. ActorType_ACTOR_TYPE_PLAYER ActorType = 1 // TEAM represents a team in the match. ActorType_ACTOR_TYPE_TEAM ActorType = 2 // COACH represents a coach in the match. ActorType_ACTOR_TYPE_COACH ActorType = 3 )
func (ActorType) Descriptor ¶
func (ActorType) Descriptor() protoreflect.EnumDescriptor
func (ActorType) EnumDescriptor
deprecated
func (ActorType) Number ¶
func (x ActorType) Number() protoreflect.EnumNumber
func (ActorType) Type ¶
func (ActorType) Type() protoreflect.EnumType
type BroadageServiceClient ¶
type BroadageServiceClient interface {
GetLiveMatches(ctx context.Context, in *GetLiveMatchesRequest, opts ...grpc.CallOption) (*GetLiveMatchesResponse, error)
GetTeamPlayers(ctx context.Context, in *GetTeamPlayersRequest, opts ...grpc.CallOption) (*GetTeamPlayersResponse, error)
GetMatchPlayers(ctx context.Context, in *GetMatchPlayersRequest, opts ...grpc.CallOption) (*GetMatchPlayersResponse, error)
GetPlayByPlay(ctx context.Context, in *GetPlayByPlayRequest, opts ...grpc.CallOption) (*GetPlayByPlayResponse, error)
}
BroadageServiceClient is the client API for BroadageService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewBroadageServiceClient ¶
func NewBroadageServiceClient(cc grpc.ClientConnInterface) BroadageServiceClient
type BroadageServiceServer ¶
type BroadageServiceServer interface {
GetLiveMatches(context.Context, *GetLiveMatchesRequest) (*GetLiveMatchesResponse, error)
GetTeamPlayers(context.Context, *GetTeamPlayersRequest) (*GetTeamPlayersResponse, error)
GetMatchPlayers(context.Context, *GetMatchPlayersRequest) (*GetMatchPlayersResponse, error)
GetPlayByPlay(context.Context, *GetPlayByPlayRequest) (*GetPlayByPlayResponse, error)
// contains filtered or unexported methods
}
BroadageServiceServer is the server API for BroadageService service. All implementations must embed UnimplementedBroadageServiceServer for forward compatibility
type EventCode ¶
type EventCode int32
EventCode represents the type of event in a match.
const ( // UNSPECIFIED represents an unspecified event. EventCode_EVENT_CODE_UNSPECIFIED EventCode = 0 // SOM represents the start of the match. EventCode_EVENT_CODE_SOM EventCode = 1 // EOM represents the end of the match. EventCode_EVENT_CODE_EOM EventCode = 2 // SOQ represents the start of a quarter. EventCode_EVENT_CODE_SOQ EventCode = 3 // EOQ represents the end of a quarter. EventCode_EVENT_CODE_EOQ EventCode = 4 )
func (EventCode) Descriptor ¶
func (EventCode) Descriptor() protoreflect.EnumDescriptor
func (EventCode) EnumDescriptor
deprecated
func (EventCode) Number ¶
func (x EventCode) Number() protoreflect.EnumNumber
func (EventCode) Type ¶
func (EventCode) Type() protoreflect.EnumType
type GetLiveMatchesRequest ¶
type GetLiveMatchesRequest struct {
// contains filtered or unexported fields
}
/ GetLiveMatchesRequest represents the request to get the live matches.
func (*GetLiveMatchesRequest) Descriptor
deprecated
func (*GetLiveMatchesRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetLiveMatchesRequest.ProtoReflect.Descriptor instead.
func (*GetLiveMatchesRequest) ProtoMessage ¶
func (*GetLiveMatchesRequest) ProtoMessage()
func (*GetLiveMatchesRequest) ProtoReflect ¶
func (x *GetLiveMatchesRequest) ProtoReflect() protoreflect.Message
func (*GetLiveMatchesRequest) Reset ¶
func (x *GetLiveMatchesRequest) Reset()
func (*GetLiveMatchesRequest) String ¶
func (x *GetLiveMatchesRequest) String() string
type GetLiveMatchesResponse ¶
type GetLiveMatchesResponse struct {
// / Matches is the list of live matches.
Matches []*MatchKey `protobuf:"bytes,1,rep,name=matches,proto3" json:"matches,omitempty"`
// contains filtered or unexported fields
}
/ GetLiveMatchesResponse represents the response to get the live matches.
func (*GetLiveMatchesResponse) Descriptor
deprecated
func (*GetLiveMatchesResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetLiveMatchesResponse.ProtoReflect.Descriptor instead.
func (*GetLiveMatchesResponse) GetMatches ¶
func (x *GetLiveMatchesResponse) GetMatches() []*MatchKey
func (*GetLiveMatchesResponse) ProtoMessage ¶
func (*GetLiveMatchesResponse) ProtoMessage()
func (*GetLiveMatchesResponse) ProtoReflect ¶
func (x *GetLiveMatchesResponse) ProtoReflect() protoreflect.Message
func (*GetLiveMatchesResponse) Reset ¶
func (x *GetLiveMatchesResponse) Reset()
func (*GetLiveMatchesResponse) String ¶
func (x *GetLiveMatchesResponse) String() string
type GetMatchPlayersRequest ¶
type GetMatchPlayersRequest struct {
// / Id is the unique identifier of the match.
MatchFid string `protobuf:"bytes,1,opt,name=match_fid,json=matchFid,proto3" json:"match_fid,omitempty"`
// contains filtered or unexported fields
}
/ BoxScore represents the box score of a match.
func (*GetMatchPlayersRequest) Descriptor
deprecated
func (*GetMatchPlayersRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetMatchPlayersRequest.ProtoReflect.Descriptor instead.
func (*GetMatchPlayersRequest) GetMatchFid ¶
func (x *GetMatchPlayersRequest) GetMatchFid() string
func (*GetMatchPlayersRequest) ProtoMessage ¶
func (*GetMatchPlayersRequest) ProtoMessage()
func (*GetMatchPlayersRequest) ProtoReflect ¶
func (x *GetMatchPlayersRequest) ProtoReflect() protoreflect.Message
func (*GetMatchPlayersRequest) Reset ¶
func (x *GetMatchPlayersRequest) Reset()
func (*GetMatchPlayersRequest) String ¶
func (x *GetMatchPlayersRequest) String() string
type GetMatchPlayersResponse ¶
type GetMatchPlayersResponse struct {
// / Match home team data, including players.
HomeTeam *MatchTeam `protobuf:"bytes,1,opt,name=home_team,json=homeTeam,proto3" json:"home_team,omitempty"`
// / Match away team data, including players.
AwayTeam *MatchTeam `protobuf:"bytes,2,opt,name=away_team,json=awayTeam,proto3" json:"away_team,omitempty"`
// contains filtered or unexported fields
}
/ GetMatchPlayersResponse represents the response to get the box score of a match.
func (*GetMatchPlayersResponse) Descriptor
deprecated
func (*GetMatchPlayersResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetMatchPlayersResponse.ProtoReflect.Descriptor instead.
func (*GetMatchPlayersResponse) GetAwayTeam ¶ added in v1.8.0
func (x *GetMatchPlayersResponse) GetAwayTeam() *MatchTeam
func (*GetMatchPlayersResponse) GetHomeTeam ¶ added in v1.8.0
func (x *GetMatchPlayersResponse) GetHomeTeam() *MatchTeam
func (*GetMatchPlayersResponse) ProtoMessage ¶
func (*GetMatchPlayersResponse) ProtoMessage()
func (*GetMatchPlayersResponse) ProtoReflect ¶
func (x *GetMatchPlayersResponse) ProtoReflect() protoreflect.Message
func (*GetMatchPlayersResponse) Reset ¶
func (x *GetMatchPlayersResponse) Reset()
func (*GetMatchPlayersResponse) String ¶
func (x *GetMatchPlayersResponse) String() string
type GetPlayByPlayRequest ¶
type GetPlayByPlayRequest struct {
// / match_fid is the unique identifier of the match.
MatchFid string `protobuf:"bytes,1,opt,name=match_fid,json=matchFid,proto3" json:"match_fid,omitempty"`
// / from_sequence_no is an optional argument specifying the number of sequence
// / from which the play by play data will be returned
FromSequenceNo *int32 `protobuf:"varint,2,opt,name=from_sequence_no,json=fromSequenceNo,proto3,oneof" json:"from_sequence_no,omitempty"`
// contains filtered or unexported fields
}
/ GetPlayByPlayRequest represents the request to get the play by play of a match.
func (*GetPlayByPlayRequest) Descriptor
deprecated
func (*GetPlayByPlayRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetPlayByPlayRequest.ProtoReflect.Descriptor instead.
func (*GetPlayByPlayRequest) GetFromSequenceNo ¶ added in v1.2.0
func (x *GetPlayByPlayRequest) GetFromSequenceNo() int32
func (*GetPlayByPlayRequest) GetMatchFid ¶
func (x *GetPlayByPlayRequest) GetMatchFid() string
func (*GetPlayByPlayRequest) ProtoMessage ¶
func (*GetPlayByPlayRequest) ProtoMessage()
func (*GetPlayByPlayRequest) ProtoReflect ¶
func (x *GetPlayByPlayRequest) ProtoReflect() protoreflect.Message
func (*GetPlayByPlayRequest) Reset ¶
func (x *GetPlayByPlayRequest) Reset()
func (*GetPlayByPlayRequest) String ¶
func (x *GetPlayByPlayRequest) String() string
type GetPlayByPlayResponse ¶
type GetPlayByPlayResponse struct {
// / PlayByPlay is the play by play of the match.
Actions []*MatchAction `protobuf:"bytes,1,rep,name=actions,proto3" json:"actions,omitempty"`
// / Events is the events of the match.
Events []*MatchEvent `protobuf:"bytes,2,rep,name=events,proto3" json:"events,omitempty"`
// contains filtered or unexported fields
}
/ GetPlayByPlayResponse represents the response to get the play by play of a match.
func (*GetPlayByPlayResponse) Descriptor
deprecated
func (*GetPlayByPlayResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetPlayByPlayResponse.ProtoReflect.Descriptor instead.
func (*GetPlayByPlayResponse) GetActions ¶
func (x *GetPlayByPlayResponse) GetActions() []*MatchAction
func (*GetPlayByPlayResponse) GetEvents ¶
func (x *GetPlayByPlayResponse) GetEvents() []*MatchEvent
func (*GetPlayByPlayResponse) ProtoMessage ¶
func (*GetPlayByPlayResponse) ProtoMessage()
func (*GetPlayByPlayResponse) ProtoReflect ¶
func (x *GetPlayByPlayResponse) ProtoReflect() protoreflect.Message
func (*GetPlayByPlayResponse) Reset ¶
func (x *GetPlayByPlayResponse) Reset()
func (*GetPlayByPlayResponse) String ¶
func (x *GetPlayByPlayResponse) String() string
type GetTeamPlayersRequest ¶
type GetTeamPlayersRequest struct {
// / Id is the unique identifier of the team.
TeamFid string `protobuf:"bytes,1,opt,name=team_fid,json=teamFid,proto3" json:"team_fid,omitempty"`
// contains filtered or unexported fields
}
/ GetPlayersFromTeamRequest represents the request to get the players from a team.
func (*GetTeamPlayersRequest) Descriptor
deprecated
func (*GetTeamPlayersRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetTeamPlayersRequest.ProtoReflect.Descriptor instead.
func (*GetTeamPlayersRequest) GetTeamFid ¶
func (x *GetTeamPlayersRequest) GetTeamFid() string
func (*GetTeamPlayersRequest) ProtoMessage ¶
func (*GetTeamPlayersRequest) ProtoMessage()
func (*GetTeamPlayersRequest) ProtoReflect ¶
func (x *GetTeamPlayersRequest) ProtoReflect() protoreflect.Message
func (*GetTeamPlayersRequest) Reset ¶
func (x *GetTeamPlayersRequest) Reset()
func (*GetTeamPlayersRequest) String ¶
func (x *GetTeamPlayersRequest) String() string
type GetTeamPlayersResponse ¶
type GetTeamPlayersResponse struct {
// / Players is the list of players from the team.
Players []*TeamPlayer `protobuf:"bytes,1,rep,name=players,proto3" json:"players,omitempty"`
// contains filtered or unexported fields
}
/ GetPlayersFromTeamResponse represents the response to get the players from a team.
func (*GetTeamPlayersResponse) Descriptor
deprecated
func (*GetTeamPlayersResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetTeamPlayersResponse.ProtoReflect.Descriptor instead.
func (*GetTeamPlayersResponse) GetPlayers ¶
func (x *GetTeamPlayersResponse) GetPlayers() []*TeamPlayer
func (*GetTeamPlayersResponse) ProtoMessage ¶
func (*GetTeamPlayersResponse) ProtoMessage()
func (*GetTeamPlayersResponse) ProtoReflect ¶
func (x *GetTeamPlayersResponse) ProtoReflect() protoreflect.Message
func (*GetTeamPlayersResponse) Reset ¶
func (x *GetTeamPlayersResponse) Reset()
func (*GetTeamPlayersResponse) String ¶
func (x *GetTeamPlayersResponse) String() string
type MatchAction ¶
type MatchAction struct {
// fid is the unique identifier of the action.
Fid string `protobuf:"bytes,1,opt,name=fid,proto3" json:"fid,omitempty"`
// team_fid is the unique identifier of the team that performed the action.
TeamFid string `protobuf:"bytes,2,opt,name=team_fid,json=teamFid,proto3" json:"team_fid,omitempty"`
// Actor represents who performed the action.
Actor *Actor `protobuf:"bytes,3,opt,name=actor,proto3" json:"actor,omitempty"`
// code identifies the action kinde
Code ActionCode `protobuf:"varint,4,opt,name=code,proto3,enum=core.broadage.v1.ActionCode" json:"code,omitempty"`
// For some action kinds, sub_code specifies additional data,
// as for the case of POINTS action, in which case sub_code specifies
// if the points were scored by a free, in-arc or out-arc throw
SubCode *ActionSubcode `protobuf:"varint,5,opt,name=sub_code,json=subCode,proto3,enum=core.broadage.v1.ActionSubcode,oneof" json:"sub_code,omitempty"`
// For some action kinds, value specifies the action value,
// as in the case of POINTS action, in which case
// value specifies the action score (1, 2 or 3 points)
Value *int32 `protobuf:"varint,6,opt,name=value,proto3,oneof" json:"value,omitempty"`
// For some action kinds, result specifies the action result,
// as in the case of POINTS action, in which case
// result specifies if the points were scored or not
Result *bool `protobuf:"varint,7,opt,name=result,proto3,oneof" json:"result,omitempty"`
// period represents the period of the match when the action occurred.
Period int32 `protobuf:"varint,8,opt,name=period,proto3" json:"period,omitempty"`
// time is the descending period ellapse, in milliseconds, when the action occurred.
Time int32 `protobuf:"varint,9,opt,name=time,proto3" json:"time,omitempty"`
// sequence is the sequence number of the action in the match.
Sequence int32 `protobuf:"varint,10,opt,name=sequence,proto3" json:"sequence,omitempty"`
// contains filtered or unexported fields
}
MatchEvent represents a single action in a match.
func (*MatchAction) Descriptor
deprecated
func (*MatchAction) Descriptor() ([]byte, []int)
Deprecated: Use MatchAction.ProtoReflect.Descriptor instead.
func (*MatchAction) GetActor ¶
func (x *MatchAction) GetActor() *Actor
func (*MatchAction) GetCode ¶
func (x *MatchAction) GetCode() ActionCode
func (*MatchAction) GetFid ¶
func (x *MatchAction) GetFid() string
func (*MatchAction) GetPeriod ¶
func (x *MatchAction) GetPeriod() int32
func (*MatchAction) GetResult ¶
func (x *MatchAction) GetResult() bool
func (*MatchAction) GetSequence ¶
func (x *MatchAction) GetSequence() int32
func (*MatchAction) GetSubCode ¶
func (x *MatchAction) GetSubCode() ActionSubcode
func (*MatchAction) GetTeamFid ¶
func (x *MatchAction) GetTeamFid() string
func (*MatchAction) GetTime ¶
func (x *MatchAction) GetTime() int32
func (*MatchAction) GetValue ¶
func (x *MatchAction) GetValue() int32
func (*MatchAction) ProtoMessage ¶
func (*MatchAction) ProtoMessage()
func (*MatchAction) ProtoReflect ¶
func (x *MatchAction) ProtoReflect() protoreflect.Message
func (*MatchAction) Reset ¶
func (x *MatchAction) Reset()
func (*MatchAction) String ¶
func (x *MatchAction) String() string
type MatchEvent ¶
type MatchEvent struct {
// The unique identifier for the event.
Fid string `protobuf:"bytes,1,opt,name=fid,proto3" json:"fid,omitempty"`
// The code representing the event kind.
Code EventCode `protobuf:"varint,2,opt,name=code,proto3,enum=core.broadage.v1.EventCode" json:"code,omitempty"`
// period represents the period of the match when the event occurred.
Period int32 `protobuf:"varint,3,opt,name=period,proto3" json:"period,omitempty"`
// time is the descending period ellapse, in milliseconds, when the event occurred.
Time int32 `protobuf:"varint,4,opt,name=time,proto3" json:"time,omitempty"`
// sequence is the sequence number of the event in the match.
Sequence int32 `protobuf:"varint,5,opt,name=sequence,proto3" json:"sequence,omitempty"`
// contains filtered or unexported fields
}
Represents an event.
func (*MatchEvent) Descriptor
deprecated
func (*MatchEvent) Descriptor() ([]byte, []int)
Deprecated: Use MatchEvent.ProtoReflect.Descriptor instead.
func (*MatchEvent) GetCode ¶
func (x *MatchEvent) GetCode() EventCode
func (*MatchEvent) GetFid ¶
func (x *MatchEvent) GetFid() string
func (*MatchEvent) GetPeriod ¶
func (x *MatchEvent) GetPeriod() int32
func (*MatchEvent) GetSequence ¶ added in v1.1.0
func (x *MatchEvent) GetSequence() int32
func (*MatchEvent) GetTime ¶
func (x *MatchEvent) GetTime() int32
func (*MatchEvent) ProtoMessage ¶
func (*MatchEvent) ProtoMessage()
func (*MatchEvent) ProtoReflect ¶
func (x *MatchEvent) ProtoReflect() protoreflect.Message
func (*MatchEvent) Reset ¶
func (x *MatchEvent) Reset()
func (*MatchEvent) String ¶
func (x *MatchEvent) String() string
type MatchKey ¶
type MatchKey struct {
// / fid is the unique id of the match.
Fid string `protobuf:"bytes,1,opt,name=fid,proto3" json:"fid,omitempty"`
// / project_key is the Match Project Key.
ProjectKey string `protobuf:"bytes,2,opt,name=project_key,json=projectKey,proto3" json:"project_key,omitempty"`
// contains filtered or unexported fields
}
/ MatchKey represents the key of a match.
func (*MatchKey) Descriptor
deprecated
func (*MatchKey) GetProjectKey ¶ added in v1.4.0
func (*MatchKey) ProtoMessage ¶
func (*MatchKey) ProtoMessage()
func (*MatchKey) ProtoReflect ¶
func (x *MatchKey) ProtoReflect() protoreflect.Message
type MatchPlayer ¶
type MatchPlayer struct {
// The unique identifier of the player.
Fid string `protobuf:"bytes,1,opt,name=fid,proto3" json:"fid,omitempty"`
// The player's number.
Number string `protobuf:"bytes,2,opt,name=number,proto3" json:"number,omitempty"`
// Indicates if the player is starting the match.
Start bool `protobuf:"varint,3,opt,name=start,proto3" json:"start,omitempty"`
// Indicates if the player is the captain of the team.
Captain bool `protobuf:"varint,4,opt,name=captain,proto3" json:"captain,omitempty"`
// contains filtered or unexported fields
}
Represents a player.
func (*MatchPlayer) Descriptor
deprecated
func (*MatchPlayer) Descriptor() ([]byte, []int)
Deprecated: Use MatchPlayer.ProtoReflect.Descriptor instead.
func (*MatchPlayer) GetCaptain ¶
func (x *MatchPlayer) GetCaptain() bool
func (*MatchPlayer) GetFid ¶
func (x *MatchPlayer) GetFid() string
func (*MatchPlayer) GetNumber ¶
func (x *MatchPlayer) GetNumber() string
func (*MatchPlayer) GetStart ¶
func (x *MatchPlayer) GetStart() bool
func (*MatchPlayer) ProtoMessage ¶
func (*MatchPlayer) ProtoMessage()
func (*MatchPlayer) ProtoReflect ¶
func (x *MatchPlayer) ProtoReflect() protoreflect.Message
func (*MatchPlayer) Reset ¶
func (x *MatchPlayer) Reset()
func (*MatchPlayer) String ¶
func (x *MatchPlayer) String() string
type MatchTeam ¶ added in v1.8.0
type MatchTeam struct {
// The unique identifier of the team.
Fid string `protobuf:"bytes,1,opt,name=fid,proto3" json:"fid,omitempty"`
// The team's match players.
Players []*MatchPlayer `protobuf:"bytes,2,rep,name=players,proto3" json:"players,omitempty"`
// contains filtered or unexported fields
}
Represents a match team.
func (*MatchTeam) Descriptor
deprecated
added in
v1.8.0
func (*MatchTeam) GetPlayers ¶ added in v1.8.0
func (x *MatchTeam) GetPlayers() []*MatchPlayer
func (*MatchTeam) ProtoMessage ¶ added in v1.8.0
func (*MatchTeam) ProtoMessage()
func (*MatchTeam) ProtoReflect ¶ added in v1.8.0
func (x *MatchTeam) ProtoReflect() protoreflect.Message
type TeamPlayer ¶
type TeamPlayer struct {
// / fid is the unique id of the player.
Fid string `protobuf:"bytes,1,opt,name=fid,proto3" json:"fid,omitempty"`
// / name is the first name of the player.
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
// / surname is the last name of the player.
Surname string `protobuf:"bytes,3,opt,name=surname,proto3" json:"surname,omitempty"`
// / number is the number of the player.
Number string `protobuf:"bytes,4,opt,name=number,proto3" json:"number,omitempty"`
// / license is the license of the player.
License string `protobuf:"bytes,5,opt,name=license,proto3" json:"license,omitempty"`
// contains filtered or unexported fields
}
/ Player represents a player in a game.
func (*TeamPlayer) Descriptor
deprecated
func (*TeamPlayer) Descriptor() ([]byte, []int)
Deprecated: Use TeamPlayer.ProtoReflect.Descriptor instead.
func (*TeamPlayer) GetFid ¶
func (x *TeamPlayer) GetFid() string
func (*TeamPlayer) GetLicense ¶
func (x *TeamPlayer) GetLicense() string
func (*TeamPlayer) GetName ¶
func (x *TeamPlayer) GetName() string
func (*TeamPlayer) GetNumber ¶
func (x *TeamPlayer) GetNumber() string
func (*TeamPlayer) GetSurname ¶
func (x *TeamPlayer) GetSurname() string
func (*TeamPlayer) ProtoMessage ¶
func (*TeamPlayer) ProtoMessage()
func (*TeamPlayer) ProtoReflect ¶
func (x *TeamPlayer) ProtoReflect() protoreflect.Message
func (*TeamPlayer) Reset ¶
func (x *TeamPlayer) Reset()
func (*TeamPlayer) String ¶
func (x *TeamPlayer) String() string
type UnimplementedBroadageServiceServer ¶
type UnimplementedBroadageServiceServer struct {
}
UnimplementedBroadageServiceServer must be embedded to have forward compatible implementations.
func (UnimplementedBroadageServiceServer) GetLiveMatches ¶
func (UnimplementedBroadageServiceServer) GetLiveMatches(context.Context, *GetLiveMatchesRequest) (*GetLiveMatchesResponse, error)
func (UnimplementedBroadageServiceServer) GetMatchPlayers ¶
func (UnimplementedBroadageServiceServer) GetMatchPlayers(context.Context, *GetMatchPlayersRequest) (*GetMatchPlayersResponse, error)
func (UnimplementedBroadageServiceServer) GetPlayByPlay ¶
func (UnimplementedBroadageServiceServer) GetPlayByPlay(context.Context, *GetPlayByPlayRequest) (*GetPlayByPlayResponse, error)
func (UnimplementedBroadageServiceServer) GetTeamPlayers ¶
func (UnimplementedBroadageServiceServer) GetTeamPlayers(context.Context, *GetTeamPlayersRequest) (*GetTeamPlayersResponse, error)
type UnsafeBroadageServiceServer ¶
type UnsafeBroadageServiceServer interface {
// contains filtered or unexported methods
}
UnsafeBroadageServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to BroadageServiceServer will result in compilation errors.